@@ -67,7 +67,7 @@ class BandoriLoader:
             return True
         
         for key, value in filters.items():
-            if obj[key] != value:
+            if obj.get(key) != value:
                 return False
         return True
     
@@ -83,17 +83,38 @@ class BandoriLoader:
             else:
                 res = []
                 for i in id:
-                    res.append(self._retrieve_response(url + str(i)))
+                    obj = self._retrieve_response(url + str(i))
+                    if self._check_filters(obj=obj, filters=filters):
+                        res.append(obj)
 
                 return res
         
         else:
             if not id:
-                return self._retrieve_response(url)
+                d = self._retrieve_response(url)
+
+                if type(d) == dict and d.get('data') is not None:
+                    d = d['data']
+                    res = []
+
+                    for o in d:
+                        if self._check_filters(obj=o, filters=filters):
+                            res.append(o)
+                
+                    return res
+                else:
+                    res = []
+                    for o in d:
+                        if self._check_filters(obj=o, filters=filters):
+                            res.append(o)
+                    return res
+
             else:
                 res = []
                 for i in id:
-                    res.append(self._retrieve_response(url + str(i)))
+                    obj = self._retrieve_response(url + str(i))
+                    if self._check_filters(obj=obj, filters=filters):
+                        res.append(obj)
                 
                 return res
     
